@@ -2,7 +2,7 @@ from .utils import encode_attr
 from .control import Control
 
 class SpinButton(Control):
-    def __init__(self, id=None, value=None, label=None, min=None, max=None, step=None,
+    def __init__(self, label=None, id=None, value=None, min=None, max=None, step=None,
             icon=None, data=None, onchange=None,
             width=None, height=None, padding=None, margin=None,
             visible=None, disabled=None):
